@@ -105,21 +105,21 @@ pub fn delete_link(address: HeaderHash) -> ExternResult<HeaderHash> {
 /// Tag filtering is a simple bytes prefix.
 ///
 /// e.g. if you had these links:
-///      - a: `[ 1, 2, 3]`
-///      - b: `[ 1, 2, 4]`
-///      - c: `[ 1, 3, 5]`
+///   - a: `[ 1, 2, 3]`
+///   - b: `[ 1, 2, 4]`
+///   - c: `[ 1, 3, 5]`
 ///
 /// Then tag filters:
-///      - `[ 1 ]` returns `[ a, b, c]`
-///      - `[ 1, 2 ]` returns `[ a, b ]`
-///      - `[ 1, 2, 3 ]` returns `[ a ]`
-///      - `[ 5 ]` returns `[ ]` (does _not_ return c because the filter is by "prefix", not "contains")
+///   - `[ 1 ]` returns `[ a, b, c]`
+///   - `[ 1, 2 ]` returns `[ a, b ]`
+///   - `[ 1, 2, 3 ]` returns `[ a ]`
+///   - `[ 5 ]` returns `[ ]` (does _not_ return c because the filter is by "prefix", not "contains")
 ///
 /// This is mostly identical to `get_link_details` but returns only creates that have not been
 /// deleted c.f. get_link_details that returns all the creates and all the deletes together.
 ///
 /// See [ `get_link_details` ].
-pub fn get_links(base: EntryHash, link_tag: Option<LinkTag>) -> ExternResult<Links> {
+pub fn get_links(base: EntryHash, link_tag: Option<LinkTag>) -> ExternResult<Vec<Link>> {
     Ok(HDK
         .with(|h| {
             h.borrow()
@@ -135,15 +135,15 @@ pub fn get_links(base: EntryHash, link_tag: Option<LinkTag>) -> ExternResult<Lin
 /// Tag filtering is a simple bytes prefix.
 ///
 /// e.g. if you had these links:
-///      - a: `[ 1, 2, 3]`
-///      - b: `[ 1, 2, 4]`
-///      - c: `[ 1, 3, 5]`
+///   - a: `[ 1, 2, 3]`
+///   - b: `[ 1, 2, 4]`
+///   - c: `[ 1, 3, 5]`
 ///
 /// then tag filters:
-///      - `[ 1 ]` returns `[ a, b, c]`
-///      - `[ 1, 2 ]` returns `[ a, b ]`
-///      - `[ 1, 2, 3 ]` returns `[ a ]`
-///      - `[ 5 ]` returns `[ ]` (does _not_ return c because the filter is by "prefix", not "contains")
+///   - `[ 1 ]` returns `[ a, b, c]`
+///   - `[ 1, 2 ]` returns `[ a, b ]`
+///   - `[ 1, 2, 3 ]` returns `[ a ]`
+///   - `[ 5 ]` returns `[ ]` (does _not_ return c because the filter is by "prefix", not "contains")
 ///
 /// This is mostly identical to get_links but it returns all the creates and all the deletes.
 /// c.f. get_links that returns only the creates that have not been deleted.
